OC.L10N.register(
    "firstrunwizard",
    {
    "About" : "Ynghylch",
    "Server address" : "Cyfeiriad gweinydd",
    "Copy link" : "Copïo dolen",
    "Copied!" : "Wedi'i gopïo!",
    "Not supported!" : "Heb ei gefnogi!",
    "Press ⌘-C to copy." : "Pwyswch ⌘-C i gopïo.",
    "Press Ctrl-C to copy." : "Pwyswch Ctrl-C i gopïo."
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
